function [out,theta_out,stdevs]=anglePhaseAverage(theta,y,bins,N)
% Phase averages columns of 'y' according to the angular position given by
% vector 'theta'

% 'theta' and 'y' must have the same number of rows 

% N (optional): Phase average over N segments per iteration (Example, N=2
% for a two, straight bladed turbine)

if size(theta,1)~=size(y,1)
    error('Number of rows in theta and y must be equal')
end

if any(theta<0) || any(theta>2*pi)
    error('theta must range fromm zero to (exclusive) 2 pi')
end
%%
if exist('N','var')
    maxTheta=2*pi/N;
    theta=mod(theta,maxTheta);
else
    maxTheta=2*pi;
end

bin_ranges=linspace(0,maxTheta,bins+1); % define bin edges
theta_out=bin_ranges(1:end-1)+maxTheta/(2*bins);
% get bin indicies and data points per ind
[bin_counts,~,bin_inds]=histcounts(theta,bin_ranges);

% Calculate phase average quantities, row is adv thetaition, column is bin
out=zeros(bins,size(y,2));
stdevs=zeros(bins,size(y,2));

for i=1:size(y,2)
    out(:,i)=accumarray(bin_inds,y(:,i),[bins 1])./bin_counts';
    % grpstats method does not deal with an empty bin, must to it manually
    stdtemp=grpstats(y(:,i),bin_inds,'std');
    if length(stdtemp)<bins
        % find the empty bin(s)
        uBins=unique(bin_inds);
        emptyBins=setdiff(1:bins,uBins);
        stdtemp(uBins)=stdtemp;
        stdtemp(emptyBins)=NaN;
%         warning('%1.0f empty bins in dataset.',length(emptyBins))
    end
    stdevs(:,i)=stdtemp;
    stdtemp=[];
end

end
