function makeTareFile
% Reads in all tare files, write mean tare values to a single file
% (tareFile.mat)
% Tare values are raw (unprocessed in magnitude or orientation) so they
% must be applied before any other calculation

% Possible fields of the tare output structure:
%    tare.DAQanalog          All AI channels from DAQ
%    tare.AMTIanalogTorque   
%    tare.AMTIforce
%    tare.AMTIalign        (an angular misalignment matrix)
%    tare.ATIalign         (an angular misalignment matrix)
%    tare.posoffset          Blade position compared to the encoder index

% load HW configuration file
load('HWconfig.mat')

%% Calculate mean of analog channels of all DAQ tare files

forceTareFiles=dir('forceTare*.mat');
if isempty(forceTareFiles)
    error('No DAQ force tare files found!')
else
    fprintf('%1.0f DAQ force tare file(s) found\n',length(forceTareFiles))
    for i=1:length(forceTareFiles)
        load(forceTareFiles(i).name);
        DAQmeans(i,:)=mean(d,1);
    end
    DAQTare=mean(DAQmeans,1);
    tare.DAQanalog=DAQTare(1:8);
end

%% Calcualte AMTI force tare and alignment values

if any(strcmp({HWconfig.inst},'AMTI top cell (digital)'))
    % AMTI force tares
    AMTITareFiles=dir('forceTare*.bin');
    if isempty(AMTITareFiles)
        warning('No AMTI force tare files found!')
    else
        fprintf('%1.0f AMTI force tare file(s) found.\n',length(AMTITareFiles))
        for i=1:length(AMTITareFiles)
            AMTIdata=readAMTIFile(AMTITareFiles(i).name);
            AMTImeans(i,:)=mean(AMTIdata(:,2:7),1);
        end
        tare.AMTIforce=mean(AMTImeans,1);
    end
    clear AMTImeans AMTIdata
end



%% Calculate the position offset tare

posTareFiles=dir('posTare*.mat');
if isempty(posTareFiles)
    warning('No turbine position tare files found!')
    tare.posoffset=0;
else
    for i=1:length(posTareFiles)
        load(posTareFiles(i).name);
        if size(d,2)>17
            col=17;
        else
            col=9;
        end
        posTare(i)=mean(-d(end-50:end,col).*2*pi/(2^16));
        if std(d(end-50:end,col))>10
            warning('Motion detected at end of position tare!')
        end
    end
    posTare=mean(posTare);
    % posMoutOffset is the blade position when the alignment fixture is in
    % place
    tare.posoffset=posMountOffset-posTare;
end

save('tareFile','tare')

end