function Process_ADV_Wake_Data

% Top / parent function for processing acoustic doppler velocimeter wake
% measurements

% Tested on MATLAB R2015b on OSX and MATLAB R2016b on Windows 10

%% Initialization

% Check current folder and set path

curDir = pwd;
[~, upperFolder, ~] = fileparts(curDir);
if strcmp(upperFolder,'ADV_wake')
    % in the correct folder, add subfolders to path
    addpath(genpath([curDir,'/Data']))
    addpath(genpath([curDir,'/Code']))
else
    error('Please change the current directory to Wake/ADV_wake, then re-run this code.\n')
end

% Define the folder names for the 3 measurement planes
parentDirs={'P_1' 'P_2' 'P_3'};

cd('Data') % change to the data folder

%% Process each measurement point, calculate phase averaged quantities

for i = 1:length(parentDirs)
    cd(parentDirs{i});
    td = []; % Array of temporal data structures
    Uinf = []; % Vector of mean free stream velocity for each measurement
    
    % Iterate through data sub-folders
    tr_files = dir('tr_*');
    
    for j = 1:length(tr_files)
        fprintf('Processing plane %.0f, subfolder %.0f of %.0f\n',i,j,length(tr_files))
        cd(tr_files(j).name)
        
        if isempty(dir('pointData.mat'))
            v3CalcPointData([],1,1); % Main turbine and ADV processing script
        end
        
        rin = load('pointData.mat');
        td = [td rin.td];
        Uinf = [Uinf rin.p.Uinf];
        cd('../')
    end
    
    Uinf = mean(Uinf);
    % clear rin
    v3PhaseAverage(2,30,1,td);
    save('mean_Uinf','Uinf')
    
    gridWakeData(parentDirs{i}); % Grid up the wake measurements
    
    % Calculate Vorticity and cleanup
    wakeDataFileName1 = [parentDirs{i},'_less_smooth.mat'];
    structIn1 = load(wakeDataFileName1);
    % Change X, Y and Z from cm to m
    structIn1.X = structIn1.X/100;
    structIn1.Y = structIn1.Y/100;
    load('phaseAvData.mat')
    structIn1.theta = paWake(1).binThetas.*180/pi; % Turbine blade position for each wake frame
    % Calculate Vorticity
    [structIn1.Vorticity,structIn1.X_vorticity,structIn1.Y_vorticity] = get_vorticity(structIn1.X,structIn1.Y,structIn1.U,structIn1.V);

    clear structIn
    
    wakeDataFileName2 = [parentDirs{i},'_more_smooth.mat'];
    structIn2 = load(wakeDataFileName2);
    % Change X, Y and Z from cm to m
    structIn2.X = structIn2.X/100;
    structIn2.Y = structIn2.Y/100;
    structIn2.theta = paWake(1).binThetas.*180/pi; % Turbine blade position for each wake frame
        % Calculate Vorticity
    [structIn2.Vorticity,structIn2.X_vorticity,structIn2.Y_vorticity] = get_vorticity(structIn2.X,structIn2.Y,structIn2.U,structIn2.V);
    
    clear mWake pa paWake structIn

    cd('../')
    
    % Save Final Wake Data Files
    save(wakeDataFileName1,'-struct','structIn1')
    save(wakeDataFileName2,'-struct','structIn2')
    
end





end
